@@ -2,20 +2,27 @@
 from .. import Linter as BaseLinter
 from .pep8 import BaseReport, StyleGuide
 
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
+
+
 
 class Linter(BaseLinter):
 
     """ PEP8 code check. """
 
     @staticmethod
-    def run(path, **meta):
+    def run(path, code=None, **options):
         """ PEP8 code checking.
 
         :return list: List of errors.
 
         """
-        P8Style = StyleGuide(reporter=_PEP8Report)
-        return P8Style.input_file(path)
+        P8Style = StyleGuide(reporter=_PEP8Report, **options)
+        buf = StringIO(code)
+        return P8Style.input_file(path, lines=buf.readlines())
 
 
 class _PEP8Report(BaseReport):
@@ -37,7 +44,7 @@ class _PEP8Report(BaseReport):
 
         self.errors.append(dict(
             text=text,
-            type=code,
+            type=code.replace('E', 'C'),
             col=offset + 1,
             lnum=line_number,
         ))
